@@ -15,11 +15,15 @@
 #
 import proto  # type: ignore
 
+from google.cloud.monitoring_dashboard_v1.types import dashboard_filter
 from google.cloud.monitoring_dashboard_v1.types import layouts
 
 
 __protobuf__ = proto.module(
-    package="google.monitoring.dashboard.v1", manifest={"Dashboard",},
+    package="google.monitoring.dashboard.v1",
+    manifest={
+        "Dashboard",
+    },
 )
 
 
@@ -71,22 +75,58 @@ class Dashboard(proto.Message):
             columns and the widgets are arranged vertically.
 
             This field is a member of `oneof`_ ``layout``.
+        dashboard_filters (Sequence[google.cloud.monitoring_dashboard_v1.types.DashboardFilter]):
+            Filters to reduce the amount of data charted
+            based on the filter criteria.
+        labels (Mapping[str, str]):
+            Labels applied to the dashboard
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=4,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=4,
+    )
     grid_layout = proto.Field(
-        proto.MESSAGE, number=5, oneof="layout", message=layouts.GridLayout,
+        proto.MESSAGE,
+        number=5,
+        oneof="layout",
+        message=layouts.GridLayout,
     )
     mosaic_layout = proto.Field(
-        proto.MESSAGE, number=6, oneof="layout", message=layouts.MosaicLayout,
+        proto.MESSAGE,
+        number=6,
+        oneof="layout",
+        message=layouts.MosaicLayout,
     )
     row_layout = proto.Field(
-        proto.MESSAGE, number=8, oneof="layout", message=layouts.RowLayout,
+        proto.MESSAGE,
+        number=8,
+        oneof="layout",
+        message=layouts.RowLayout,
     )
     column_layout = proto.Field(
-        proto.MESSAGE, number=9, oneof="layout", message=layouts.ColumnLayout,
+        proto.MESSAGE,
+        number=9,
+        oneof="layout",
+        message=layouts.ColumnLayout,
+    )
+    dashboard_filters = proto.RepeatedField(
+        proto.MESSAGE,
+        number=11,
+        message=dashboard_filter.DashboardFilter,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=12,
     )
 
 
