@@ -29,10 +29,8 @@ class TableDisplayOptions(proto.Message):
 
     Attributes:
         shown_columns (Sequence[str]):
-            Optional. Columns to display in the table.
-            Leave empty to display all available columns.
-            Note: This field is for future features and is
-            not currently used.
+            Optional. This field is unused and has been replaced by
+            TimeSeriesTable.column_settings
     """
 
     shown_columns = proto.RepeatedField(
